<?php

namespace Newage\Vote\Providers;

use Illuminate\Support\ServiceProvider;

class VoteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'vote');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'vote');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('newage.vote', function ($app) {
            return $this->app->make('Newage\Vote\Vote');
        });

        // Bind VoteItem to repository
        $this->app->bind(
            'Newage\Vote\Interfaces\VoteItemRepositoryInterface',
            \Newage\Vote\Repositories\Eloquent\VoteItemRepository::class
        );        // Bind VoteTopic to repository
        $this->app->bind(
            'Newage\Vote\Interfaces\VoteTopicRepositoryInterface',
            \Newage\Vote\Repositories\Eloquent\VoteTopicRepository::class
        );        // Bind VoteVoter to repository
        $this->app->bind(
            'Newage\Vote\Interfaces\VoteVoterRepositoryInterface',
            \Newage\Vote\Repositories\Eloquent\VoteVoterRepository::class
        );

        $this->app->register(\Newage\Vote\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Newage\Vote\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['newage.vote'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('newage/vote.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/vote')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/vote')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
